//
//  CKs Time Zone Picker
//
//  Created by C.K. Haun on 3/27/14.
//  Copyright (c) 2014 Ravenware Industries LLC. All rights reserved.
//

#import "ckTZPickerControl.h"

@implementation ckTZPickerControl
@synthesize zonesBundle  ,currentCity,currentArea ,currentElement;
-(void)awakeFromNib{
    // get all the time zone names the system knows about in my bundle format
    zonesBundle = [[ckTimeZoneListBundle alloc]init];

    self.dataSource =  self;
    self.delegate=self;
    // set the picker wheels to zero sero
    [self setZoneValueByValues:0 andZone:0];

}

#pragma mark data source
// returns the number of 'columns' to display.  Two, the regione and the citys
- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView{
    return 2;
}
// returns the # of rows in each component.
// either the number of regions, for the left wheel, or the number of cities for that region in
//the right wheel
- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component{
    NSInteger retVal=0;
    ckTimeZoneListCluster *temp;
    switch (component) {
        case 0:
            retVal=[zonesBundle.clusters count];  // how many regions
            break;
        case 1:
            temp = [zonesBundle.clusters objectAtIndex:currentArea]; // how many cities
            retVal=           [temp.elements count];
            break;
    }
    return (retVal);
}
// Get the region name for the left wheel, the city name for the right
- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component{
    NSString *theS;
    ckTimeZoneListCluster *temp;    
    ckTimeZoneListElement *temp2;
    switch (component) {
        case 0:
            temp = [zonesBundle.clusters objectAtIndex:row];
            theS = temp.header;
            break;
            case 1:
            temp = [zonesBundle.clusters objectAtIndex:currentArea];
            temp2 = [temp.elements objectAtIndex:row];
            theS = temp2.city;
            break;

    }
    return theS;
}

#pragma mark protocol
// when the wheel changes we update the currently selected cluster that we are
// tracking so others can observe it and take action if necessary
- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component{

    switch (component) {
        case 0:
            currentArea = row;
            currentCity=0;
            [self reloadAllComponents];
            [self selectRow:0 inComponent:1 animated:YES];  // scrolls the specified row to center.
            break;
        case 1:
            currentCity=row;
            break;
    }
    ckTimeZoneListCluster *temp = [zonesBundle.clusters objectAtIndex:currentArea];
    self.currentElement =[temp.elements objectAtIndex:currentCity];
}

//  Allows you to force-feed the wheels to select a previously save time zone,
// used by the next method
-(void)setZoneValueByValues:(NSInteger)area andZone:(NSInteger)city{
    currentArea=area;
    currentCity=city;
    [self reloadAllComponents];

    [self selectRow:area inComponent:0 animated:YES];  // scrolls the specified row to center.
    [self selectRow:city inComponent:1 animated:YES];  // scrolls the specified row to center.
    ckTimeZoneListCluster *temp = [zonesBundle.clusters objectAtIndex:currentArea];
    currentElement =[temp.elements objectAtIndex:currentCity];

}
// Pass in a time zone element and set the wheels to that element
// obviously useful if you are saving user choices
-(void)setZoneValueByElement:(ckTimeZoneListElement *)element{
    NSInteger inCluser = [zonesBundle inWhichCluster:element];
    ckTimeZoneListCluster *temp = [zonesBundle.clusters objectAtIndex:inCluser];
    NSInteger elementInCluser =[temp elementInCluster:element];
    [self setZoneValueByValues:inCluser andZone:elementInCluser];
}

// gets teh '/' name for the currently selected element.
-(NSString *)getCurrentZoneString{
    NSString *theS=nil;

    theS=currentElement.completeName;
    
    return (theS);
    
    
}
@end
